SSHServer class

Constructors

SSHServer({required String host, int port = 443, required String username, required String password, required SSHIOSConfiguration iosConfiguration, required String udpgw, int udpgwPort = 7300})

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → String
final
iosConfiguration → SSHIOSConfiguration
final
password → String
final
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
udpgw → String
final
udpgwPort → int
final
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited