SshvpnFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • SshvpnFlutterPlatform
Implementers

Constructors

SshvpnFlutterPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() → Future<bool?>
disconnect() → Future<bool?>
lastStatus() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setup({required SSHServer server}) → Future<bool?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ SshvpnFlutterPlatform
getter/setter pair